#!/bin/bash
# ESA (C) 2000-2018 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#
export STSPHOME=/home/tcxgen/tm
export STSPBIN=/home/tcxgen/tmproc

mkdir -p $STSPHOME/new
mkdir -p $STSPHOME/spare
mkdir -p $STSPHOME/error
mkdir -p $STSPHOME/warning
mkdir -p $STSPHOME/processed/data
mkdir -p $STSPHOME/processed/ps
mkdir -p $STSPHOME/processed/log
mkdir -p $STSPHOME/processed/stsp

LHEASOFT=/usr/local/lheasoft5.3/i686-pc-linux-gnu
export LHEASOFT
. $LHEASOFT/lhea-init.sh

#
# Set up SAS Paths
OLDPATH=$PATH
#### jdp 20071102 
#### export SAS_DIR=/sas/Linux/RedHat9/sas6_5_0
export SAS_DIR=/xdata/sas/Linux/RedHat9/xmmsas_20070708_1801
export SAS_PATH=$STSPBIN:$SAS_DIR
. $SAS_DIR/sas-setup.sh
export PATH=/usr/local/bin/:$PATH:$OLDPATH

cd $STSPHOME

#
# Get the orbita file from the website  
wget -q http://xmm.vilspa.esa.es/~xmmdoc/orbit/data/orbita.tar.gz -O $STSPHOME/fds/orbita.tar.gz

#
# Untar it
tar zxf $STSPHOME/fds/orbita.tar.gz  -C $STSPHOME/fds

#
# Get the Revolution number from the website
wget -q http://xmm.vilspa.esa.es/~xmmdoc/orbit/data/revno -O $STSPHOME/fds/revno

#
# Format it into the required form
grep "START REVOLUTION" $STSPHOME/fds/revno | awk '{print $7,$4}' > $STSPHOME/revno.txt

#
# Move newly created files to new directory
if [ -f $STSPHOME/RTX_* ]; then
    mv -f $STSPHOME/RTX_* $STSPHOME/spare/
fi

#
# Move any remnant from previous runs to processed directory
if [ -f  $STSPHOME/new/* ]; then
    mv -f $STSPHOME/new/* $STSPHOME/spare/
fi

#
# Get the revolution number
currentrev=`whichrev -V 0`

let firstrev=$(( $currentrev - 4 ))

for ((i = $firstrev; i < $currentrev; i++)) ; do

	if (($i%30==0));
	then
	       	rm $STSPHOME/rawtm/*DAT;
	fi;

	if [ -f $STSPHOME/processed/data/RTX_$i*.FIT ]; then
		echo "RTX file for revolution $i exists";
	else
		echo "Running stspproc for Revolution $i"

		#
		# Run the task
		stspproc --revolution=$i --useS2K=yes > $STSPHOME/RTX_run_$i.log 2>&1

		#
		# Move newly created files to new directory
		mv -f $STSPHOME/RTX_* $STSPHOME/new/

		#
		# Look for errors
		nErrors=`grep ERROR $STSPHOME/new/RTX_*log | wc -l`

		if (( $nErrors != 0)); then

    		echo "stspproc failed for Revolution" $i
    		cat $STSPHOME/new/*.log
    		mv -f $STSPHOME/new/* $STSPHOME/error/

		else

    		nWarnings=`grep WARNING $STSPHOME/new/RTX_*log | wc -l`

    		if (( $nWarnings != 0)); then

				echo "stspproc completed with warnings for Revolution" $i
				cat $STSPHOME/new/*.log
				mv -f $STSPHOME/new/* $STSPHOME/warning/

    		else

				echo "stspproc completed successfully for Revolution " $i
				mv -f $STSPHOME/new/RTX*FIT  $STSPHOME/processed/data/
				mv -f $STSPHOME/new/RTX*ps   $STSPHOME/processed/ps/
				mv -f $STSPHOME/new/RTX*log  $STSPHOME/processed/log/
				mv -f $STSPHOME/new/RTX*stsp $STSPHOME/processed/stsp/


    		fi

		fi
	fi
done

let checkrev=$(( $currentrev - 5 ))

if [ -f $STSPHOME/processed/data/RTX_$checkrev*.FIT ]; then
	echo "RTX file for revolution "$checkrev exists;
else
	echo "RTX file for " $checkrev " does not exist. Better check!"
fi
