#!/bin/bash
# ESA (C) 2000-2018 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#
# stsp_runloop.sh 
#
# Script for looping over latest revs and running the TCX gen
#
# Env vars used: 
#    STSPHOME
#    STSPRAWDELETION
#    STSPREVLOOP
#    STSPREVCHECK
#
# CR x4 8-Oct-08 New env var for customizing the main loop

echo "stsp_runloop starting"
date

echo "STARTING LOOP PROCCESSING"
echo "========================="
#
# Get the revolution number
currentrev=`whichrev -V 0`

#let firstrev=$(( $currentrev - 4 ))
let firstrev=$(( $currentrev - $STSPREVLOOP ))

for ((i = $firstrev; i < $currentrev; i++)) ; do

	#if (($i%30==0));
	if (($i%$STSPRAWDELETION==0));
	then
	       	rm $STSPHOME/rawtm/*DAT;
	fi;
 
	echo "Calling runrev $i ";
        stsp_runrev.sh $i

done

echo "Final check about -5 revs"

#let checkrev=$(( $currentrev - 5 ))
let checkrev=$(( $currentrev - $STSPREVCHECK ))

if [ -f $STSPHOME/processed/data/RTX_$checkrev*.FIT ]; then
	echo "RTX file for revolution "$checkrev exists;
else
	echo "RTX file for " $checkrev " does not exist. Better check!"
fi

echo "stsp_runloop ending"
