// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include "TCS.h"
#include "Utils.h"

#include "param.h"
#include "CalOalUtility.h"

#include <sstream>
#include <vector>
#include <map>

TCS::TCS(TCSfiles::type type, int rev, int obsid) {

  dataSet = 0;

  fileType = type;

  stringstream s;

  s.width(4); s.fill('0');
  s << rev << "_";

  s.width(10); s.fill('0');
  s << obsid << "_";

  
  if (type == TCSfiles::TCS) {
	  tablename = "SCTCS1";
	  s << "SCX00000TCS.FIT";
  }
  else {
	  tablename = "SCRTX1";  
	  s << "SCX00000TCX.FIT";
  }

  filename = s.str();
  
  // Set up the data pointers
  open();

}


void TCS::close() {

  // Close the dataset  
  dataSetServer->close(dataSet);
  dataSet = 0;
  
  // Go through and release memory

}

void TCS::open(Dal::AccessMode mode) {


  if (dataSet == 0) {
    dataSet = dataSetServer->open( getFilename(), mode );
    tab     = dataSet->table( 0 );
  }

  frameCol   = tab->column("FRAME");
  obtcCol    = tab->column("OBTCOARS");
  obtfCol    = tab->column("OBTFINE");
  utcdayCol  = tab->column("UTCDAY");
  utcmilCol  = tab->column("UTCMILLI");
  utcmicCol  = tab->column("UTCMICRO");
  utcflagCol = tab->column("UTCFLAG");
  corrparaCol = tab->column("CORRPARA");
  corrparbCol = tab->column("CORRPARB");
  ertCol     = tab->column("ERTIME");
  gsidCol    = tab->column("GSID");
  ertrawCol  = tab->column("ERTIMRAW");

  // Get the column data
  frameColD   = frameCol->data();
  obtcColD    = obtcCol->data();
  obtfColD    = obtfCol->data();
  utcdayColD  = utcdayCol->data();
  utcmilColD  = utcmilCol->data();
  utcmicColD  = utcmicCol->data();
  utcflagColD = utcflagCol->data();
  corrparaColD = corrparaCol->data();
  corrparbColD = corrparbCol->data();
  ertColD     = ertCol->data();
  gsidColD    = gsidCol->data();
  ertrawColD  = ertrawCol->data();

  // Get pointers to the data
  frameData   = frameColD->int32Data();
  obtcData    = obtcColD->int32Data();
  obtfData    = obtfColD->uint16Data();
  utcdayData  = utcdayColD->int16Data();
  utcmilData  = utcmilColD->int32Data();
  utcmicData  = utcmicColD->int16Data();
  utcflagData = utcflagColD->int16Data();

}

string TCS::getFilename() {

  return filename;

}

string TCS::getTablename() {

  return tablename;

}
