// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include <iostream>

#include "tcsdump.h"
#include "TCS.h"
#include "CalOalUtility.h"
#include "Utils.h"
#include "STime.h"

inline double convertToDouble(const std::string& s);

///////////////////////
//
//
//
//
void tcsdump () {
  
  string infile = stringParameter("file");

  int revno = atoi(infile.substr(0,4).c_str());
  int obsid = atoi(infile.substr(5,10).c_str());

  TCS tcsfile(TCSfiles::TCS, revno, obsid);

  for (unsigned int i = 0; i < tcsfile.tab->rows(); i++ ) {

    int TCSOBTC = tcsfile.obtcData[i];
    int TCSOBTF = tcsfile.obtfData[i];
    STime TCSERT(CalOalUtility::stringColumnRow(tcsfile.ertColD, i));
    STime TCSRAWERT(CalOalUtility::stringColumnRow(tcsfile.ertrawColD, i));
	double TCSCORRPARA = convertToDouble(CalOalUtility::stringColumnRow(tcsfile.corrparaColD, i));
	double TCSCORRPARB = convertToDouble(CalOalUtility::stringColumnRow(tcsfile.corrparbColD, i));
    string TCSgsid(CalOalUtility::stringColumnRow(tcsfile.gsidColD, i));
 
    double OBT = (double)TCSOBTC + (double)TCSOBTF / 65536.0; 

	std::cout.precision(16);
	std::cout 
		<< "GS: "
		<< TCSgsid 
		<< " OBT: "
		<< OBT
		<< " RawERT: " 
		<< TCSRAWERT.modifiedJulianDay().full()
		<< " TCS: "
		<< TCSERT.modifiedJulianDay().full()
		<< " Slope: "
		<< TCSCORRPARA
		<< " Intercept: "
		<< TCSCORRPARB
		<< std::endl; 

  }

}

inline double convertToDouble(const std::string& s)
{
	std::istringstream i(s);

	double x;
	
	i >> x;	

	return x;

} 

